about summary refs log tree commit diff
path: root/pkgs/by-name/on
diff options
context:
space:
mode:
authorAnderson Torres <torres.anderson.85@protonmail.com>2024-05-10 20:36:30 -0300
committerAnderson Torres <torres.anderson.85@protonmail.com>2024-06-04 08:19:10 -0300
commit523f2542111b172b8f979e53e0ad68bf71928dfb (patch)
treef58e0b5682f9a1b81c3cf2f712bcaaa0c7f2286d /pkgs/by-name/on
parent9d630a3eb3780fb8e2398ae957d630479bbf537c (diff)
onscripter-en: 20111009 -> 20110930
Not a real update, just a new source and a new maintainer
Diffstat (limited to 'pkgs/by-name/on')
-rw-r--r--pkgs/by-name/on/onscripter-en/package.nix71
1 files changed, 50 insertions, 21 deletions
diff --git a/pkgs/by-name/on/onscripter-en/package.nix b/pkgs/by-name/on/onscripter-en/package.nix
index edc9e20235ffe..7178deaca64dc 100644
--- a/pkgs/by-name/on/onscripter-en/package.nix
+++ b/pkgs/by-name/on/onscripter-en/package.nix
@@ -1,38 +1,67 @@
-{ lib, stdenv, fetchurl
-, libpng, libjpeg, libogg, libvorbis, freetype, smpeg
-, SDL, SDL_image, SDL_mixer, SDL_ttf }:
+{
+  lib,
+  SDL,
+  SDL_image,
+  SDL_mixer,
+  SDL_ttf,
+  fetchFromGitHub,
+  freetype,
+  libjpeg,
+  libogg,
+  libpng,
+  libvorbis,
+  pkg-config,
+  smpeg,
+  stdenv,
+}:
 
 
-stdenv.mkDerivation {
+stdenv.mkDerivation (finalAttrs: {
   pname = "onscripter-en";
-  version = "20111009";
+  version = "20110930";
 
-  src = fetchurl {
-    # The website is not available now.
-    url = "https://www.dropbox.com/s/ag21owy9poyr2oy/onscripter-en-20111009-src.tar.bz2";
-    sha256 = "sha256-pir3ExhehJ9zNygDN83S4GOs5ugDNMjngxEwklAz9c8=";
+  # The website is not available now. Let's use a Museoa backup
+  src = fetchFromGitHub {
+    owner = "museoa";
+    repo = "onscripter-en";
+    rev = finalAttrs.version;
+    hash = "sha256-Lc5ZlH2C4ER02NmQ6icfiqpzVQdVUnOmdywGjjjSYSg=";
   };
 
-  buildInputs = [ libpng libjpeg libogg libvorbis freetype smpeg
-                  SDL SDL_image SDL_mixer SDL_ttf
-                ];
+  nativeBuildInputs = [
+    SDL
+    pkg-config
+    smpeg
+  ];
+
+  buildInputs = [
+    SDL
+    SDL_image
+    SDL_mixer
+    SDL_ttf
+    freetype
+    libjpeg
+    libogg
+    libpng
+    libvorbis
+    smpeg
+  ];
 
   configureFlags = [ "--no-werror" ];
 
-  # Without this libvorbisfile.so is not getting linked properly for some reason.
-  NIX_CFLAGS_LINK = "-lvorbisfile";
+  strictDeps = true;
 
   preBuild = ''
     sed -i 's/.dll//g' Makefile
   '';
 
-  meta = with lib; {
-    broken = stdenv.isDarwin;
+  meta = {
+    homepage = "http://github.com/museoa/onscripter-en";
     description = "Japanese visual novel scripting engine";
+    license = lib.licenses.gpl2Plus;
     mainProgram = "onscripter-en";
-    homepage = "http://unclemion.com/onscripter/";
-    license = licenses.gpl2;
-    platforms = platforms.unix;
-    maintainers = with maintainers; [ abbradar ];
+    maintainers = with lib.maintainers; [ AndersonTorres abbradar ];
+    platforms = lib.platforms.unix;
+    broken = stdenv.isDarwin;
   };
-}
+})